@@ -9,6 +9,7 @@ from plexus.common.utils.strutils import dot_case_parser, dot_case_pattern
 from plexus.common.utils.strutils import hex_string_parser, hex_string_pattern
 from plexus.common.utils.strutils import kebab_case_parser, kebab_case_pattern
 from plexus.common.utils.strutils import parse_bag_name, parse_user_name, parse_vehicle_name
+from plexus.common.utils.strutils import semver_parser, semver_pattern
 from plexus.common.utils.strutils import snake_case_parser, snake_case_pattern
 from plexus.common.utils.strutils import strict_abspath_parser, strict_abspath_pattern
 from plexus.common.utils.strutils import strict_relpath_parser, strict_relpath_pattern
@@ -376,6 +377,44 @@ class StrUtilsTest(unittest.TestCase):
         with self.assertRaises(pp.ParseException):
             strict_abspath_parser.parse_string(data, parse_all=True)
 
+    data_semver_pattern = [
+        ("0.0.0",),
+        ("1.2.3",),
+        ("10.20.30",),
+        ("0.1.0-alpha",),
+        ("1.0.0+build.1",),
+        ("1.0.0-alpha+build.1",),
+        ("1.0.0-0.3.7",),
+        ("1.0.0-x.7.z.92",),
+    ]
+
+    @ddt.idata(data_semver_pattern)
+    @ddt.unpack
+    def test_semver_pattern(self, data):
+        self.assertIsNotNone(semver_pattern.match(data))
+        self.assertIsNotNone(semver_parser.parse_string(data, parse_all=True))
+
+    data_semver_pattern__bad_cases = [
+        ("",),
+        ("dummy",),
+        ("1",),
+        ("1.0",),
+        ("01.0.0",),
+        ("0.01.0",),
+        ("0.0.01",),
+        ("1.0.0-",),
+        ("1.0.0+",),
+        ("1.0.0-alpha+",),
+        ("1.0.0-alpha+beta-",),
+    ]
+
+    @ddt.idata(data_semver_pattern__bad_cases)
+    @ddt.unpack
+    def test_semver_pattern__bad_cases(self, data):
+        self.assertIsNone(semver_pattern.match(data))
+        with self.assertRaises(pp.ParseException):
+            semver_parser.parse_string(data, parse_all=True)
+
     data_tag_pattern = [
         ("dummy",),
         ("dummy::dummy",),
